summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codeimport/kdevcppparser/urlutil.h')
-rw-r--r--umbrello/umbrello/codeimport/kdevcppparser/urlutil.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h b/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
index d243ddbd..2d05b162 100644
--- a/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
+++ b/umbrello/umbrello/codeimport/kdevcppparser/urlutil.h
@@ -38,13 +38,13 @@ namespace URLUtil
*/
TQString directory(const TQString & pathName);
/**
* Returns the relative path between a tqparent and child URL, or blank if the specified child is not a child of tqparent
*/
- TQString relativePath(const KURL & tqparent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
/**
* Returns the relative path between a tqparent and child URL, or blank if the specified child is not a child of tqparent
*/
- TQString relativePath(const TQString & tqparent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const TQString & parent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
/**
* Returns the relative path between a directory and file. Should never return empty path.
* Example:
@@ -38,13 +38,13 @@ namespace URLUtil
TQString directory(const TQString & pathName);
/**
- * Returns the relative path between a tqparent and child URL, or blank if the specified child is not a child of tqparent
+ * Returns the relative path between a parent and child URL, or blank if the specified child is not a child of parent
*/
@@ -38,13 +38,13 @@ namespace URLUtil
/**
- * Returns the relative path between a tqparent and child URL, or blank if the specified child is not a child of tqparent
+ * Returns the relative path between a parent and child URL, or blank if the specified child is not a child of parent
*/